//
//    FILE: MS5611_test.ino
//  AUTHOR: Rob Tillaart
// PURPOSE: demo application
//    DATE: 2014-okt-16
//     URL: https://github.com/RobTillaart/MS5611


#include "MS5611.h"


MS5611 MS5611(0x77);   // 0x76 = CSB to VCC; 0x77 = CSB to GND


void setup()
{
  Serial.begin(115200);
  Serial.print(__FILE__);
  Serial.print("MS5611_LIB_VERSION: ");
  Serial.println(MS5611_LIB_VERSION);

  if (MS5611.begin() == true)
  {
    Serial.println("MS5611 found.");
  }
  else
  {
    Serial.println("MS5611 not found. halt.");
    while(1);
  }
  /*
  There are 5 oversampling settings, each corresponding to a different amount of milliseconds
  The higher the oversampling, the more accurate the reading will be, however the longer it will take.
  OSR_ULTRA_HIGH -> 10 millis
  OSR_HIGH       -> 5 millis
  OSR_STANDARD   -> 3 millis
  OSR_LOW        -> 2 millis
  OSR_ULTRA_LOW  -> 1 millis   Default = backwards compatible
  */
  MS5611.setOversampling(OSR_ULTRA_HIGH);
}


void loop()
{
  int result = MS5611.read();
  if (result != MS5611_READ_OK)
  {
    Serial.print("Error in read: ");
    Serial.println(result);
  }
  else
  {
    Serial.print("\nT:\t");
    Serial.print(MS5611.getTemperature(), 2);
    Serial.print("\tP:\t");
    Serial.print(MS5611.getPressure(), 2);
  }
  delay(1000);
}


// -- END OF FILE --

